@@ -10,7 +10,7 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	/* Create dialog with OK and Cancel buttons. Leave the separator out,
 	 * as we do not have any content. */
 	dialog = gtk_dialog_new_with_buttons(
-		"Hello control panel",
+		"mmmRemotePhoneControl config",
 		GTK_WINDOW(data),
 		GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
 		GTK_STOCK_OK,
